@@ -17,10 +17,18 @@
 
 #include "secret-private.h"
 
-#ifdef WITH_GCRYPT
+#ifdef WITH_CRYPTO
 #include "egg/egg-dh.h"
 #include "egg/egg-hkdf.h"
+#endif
+
+#ifdef WITH_GCRYPT
 #include "egg/egg-libgcrypt.h"
+#include <gcrypt.h>
+#endif
+
+#ifdef WITH_GNUTLS
+#include <gnutls/crypto.h>
 #endif
 
 #include "egg/egg-hex.h"
@@ -36,10 +44,10 @@ EGG_SECURE_DECLARE (secret_session);
 struct _SecretSession {
 	gchar *path;
 	const gchar *algorithms;
-#ifdef WITH_GCRYPT
-	gcry_mpi_t prime;
-	gcry_mpi_t privat;
-	gcry_mpi_t publi;
+#ifdef WITH_CRYPTO
+	egg_dh_params *params;
+	egg_dh_privkey *privat;
+	egg_dh_pubkey *publi;
 #endif
 	gpointer key;
 	gsize n_key;
@@ -54,55 +62,52 @@ _secret_session_free (gpointer data)
 		return;
 
 	g_free (session->path);
-#ifdef WITH_GCRYPT
-	gcry_mpi_release (session->publi);
-	gcry_mpi_release (session->privat);
-	gcry_mpi_release (session->prime);
+#ifdef WITH_CRYPTO
+	egg_dh_pubkey_free (session->publi);
+	egg_dh_privkey_free (session->privat);
+	egg_dh_params_free (session->params);
 #endif
 	egg_secure_free (session->key);
 	g_free (session);
 }
 
-#ifdef WITH_GCRYPT
+#ifdef WITH_CRYPTO
 
 static GVariant *
 request_open_session_aes (SecretSession *session)
 {
-	gcry_error_t gcry;
-	gcry_mpi_t base;
-	unsigned char *buffer;
-	size_t n_buffer;
+	GBytes *buffer;
 	GVariant *argument;
 
-	g_assert (session->prime == NULL);
+	g_assert (session->params == NULL);
 	g_assert (session->privat == NULL);
 	g_assert (session->publi == NULL);
 
+#ifdef WITH_GCRYPT
 	egg_libgcrypt_initialize ();
+#endif
 
 	/* Initialize our local parameters and values */
-	if (!egg_dh_default_params ("ietf-ike-grp-modp-1024",
-	                            &session->prime, &base))
+	session->params = egg_dh_default_params ("ietf-ike-grp-modp-1024");
+	if (!session->params)
 		g_return_val_if_reached (NULL);
 
 #if 0
-	g_printerr ("\n lib prime: ");
-	gcry_mpi_dump (session->prime);
-	g_printerr ("\n  lib base: ");
-	gcry_mpi_dump (base);
+	g_printerr ("\n lib params: ");
+	egg_dh_params_dump (session->params);
 	g_printerr ("\n");
 #endif
 
-	if (!egg_dh_gen_pair (session->prime, base, 0,
+	if (!egg_dh_gen_pair (session->params, 0,
 	                      &session->publi, &session->privat))
 		g_return_val_if_reached (NULL);
-	gcry_mpi_release (base);
 
-	gcry = gcry_mpi_aprint (GCRYMPI_FMT_USG, &buffer, &n_buffer, session->publi);
-	g_return_val_if_fail (gcry == 0, NULL);
-	argument = g_variant_new_from_data (G_VARIANT_TYPE ("ay"),
-	                                    buffer, n_buffer, TRUE,
-	                                    gcry_free, buffer);
+	buffer = egg_dh_pubkey_export (session->publi);
+	g_return_val_if_fail (buffer != NULL, NULL);
+	argument = g_variant_new_from_bytes (G_VARIANT_TYPE ("ay"),
+					     buffer,
+					     TRUE);
+	g_bytes_unref (buffer);
 
 	return g_variant_new ("(sv)", ALGORITHMS_AES, argument);
 }
@@ -111,14 +116,11 @@ static gboolean
 response_open_session_aes (SecretSession *session,
                            GVariant *response)
 {
-	gconstpointer buffer;
+	GBytes *buffer;
 	GVariant *argument;
 	const gchar *sig;
-	gsize n_buffer;
-	gcry_mpi_t peer;
-	gcry_error_t gcry;
-	gpointer ikm;
-	gsize n_ikm;
+	egg_dh_pubkey *peer;
+	GBytes *ikm;
 
 	sig = g_variant_get_type_string (response);
 	g_return_val_if_fail (sig != NULL, FALSE);
@@ -131,24 +133,27 @@ response_open_session_aes (SecretSession *session,
 	g_assert (session->path == NULL);
 	g_variant_get (response, "(vo)", &argument, &session->path);
 
-	buffer = g_variant_get_fixed_array (argument, &n_buffer, sizeof (guchar));
-	gcry = gcry_mpi_scan (&peer, GCRYMPI_FMT_USG, buffer, n_buffer, NULL);
-	g_return_val_if_fail (gcry == 0, FALSE);
+	buffer = g_variant_get_data_as_bytes (argument);
+	peer = egg_dh_pubkey_new_from_bytes (session->params, buffer);
+	g_bytes_unref (buffer);
+	g_return_val_if_fail (peer != NULL, FALSE);
 	g_variant_unref (argument);
 
 #if 0
 	g_printerr (" lib publi: ");
-	gcry_mpi_dump (session->publi);
+	egg_dh_pubkey_dump (session->publi);
 	g_printerr ("\n  lib peer: ");
-	gcry_mpi_dump (peer);
+	egg_dh_pubkey_dump (peer);
 	g_printerr ("\n");
 #endif
 
-	ikm = egg_dh_gen_secret (peer, session->privat, session->prime, &n_ikm);
-	gcry_mpi_release (peer);
+	ikm = egg_dh_gen_secret (peer, session->privat, session->params);
+	egg_dh_pubkey_free (peer);
 
 #if 0
-	g_printerr ("   lib ikm:  %s\n", egg_hex_encode (ikm, n_ikm));
+	g_printerr ("   lib ikm:  %s\n",
+		    egg_hex_encode (g_bytes_get_data (ikm, NULL),
+				    g_bytes_get_size (ikm)));
 #endif
 
 	if (ikm == NULL) {
@@ -160,16 +165,19 @@ response_open_session_aes (SecretSession *session,
 
 	session->n_key = 16;
 	session->key = egg_secure_alloc (session->n_key);
-	if (!egg_hkdf_perform ("sha256", ikm, n_ikm, NULL, 0, NULL, 0,
+	if (!egg_hkdf_perform ("sha256",
+			       g_bytes_get_data (ikm, NULL),
+			       g_bytes_get_size (ikm),
+			       NULL, 0, NULL, 0,
 	                       session->key, session->n_key))
 		g_return_val_if_reached (FALSE);
-	egg_secure_free (ikm);
+	g_bytes_unref (ikm);
 
 	session->algorithms = ALGORITHMS_AES;
 	return TRUE;
 }
 
-#endif /* WITH_GCRYPT */
+#endif /* WITH_CRYPTO */
 
 static GVariant *
 request_open_session_plain (SecretSession *session)
@@ -252,7 +260,7 @@ on_service_open_session_plain (GObject *source,
 	g_object_unref (task);
 }
 
-#ifdef WITH_GCRYPT
+#ifdef WITH_CRYPTO
 
 static void
 on_service_open_session_aes (GObject *source,
@@ -301,7 +309,7 @@ on_service_open_session_aes (GObject *source,
 	g_object_unref (task);
 }
 
-#endif /* WITH_GCRYPT */
+#endif /* WITH_CRYPTO */
 
 
 void
@@ -320,7 +328,7 @@ _secret_session_open (SecretService *service,
 	g_task_set_task_data (task, closure, open_session_closure_free);
 
 	g_dbus_proxy_call (G_DBUS_PROXY (service), "OpenSession",
-#ifdef WITH_GCRYPT
+#ifdef WITH_CRYPTO
 	                   request_open_session_aes (closure->session),
 	                   G_DBUS_CALL_FLAGS_NONE, -1,
 	                   cancellable, on_service_open_session_aes,
@@ -346,7 +354,7 @@ _secret_session_open_finish (GAsyncResult *result,
 	return TRUE;
 }
 
-#ifdef WITH_GCRYPT
+#ifdef WITH_CRYPTO
 
 static gboolean
 pkcs7_unpad_bytes_in_place (guchar *padded,
@@ -378,6 +386,8 @@ pkcs7_unpad_bytes_in_place (guchar *padded,
 	return TRUE;
 }
 
+#ifdef WITH_GCRYPT
+
 static SecretValue *
 service_decode_aes_secret (SecretSession *session,
                            gconstpointer param,
@@ -393,12 +403,12 @@ service_decode_aes_secret (SecretSession *session,
 	gsize pos;
 
 	if (n_param != 16) {
-		g_message ("received an encrypted secret structure with invalid parameter");
+		g_info ("received an encrypted secret structure with invalid parameter");
 		return NULL;
 	}
 
 	if (n_value == 0 || n_value % 16 != 0) {
-		g_message ("received an encrypted secret structure with bad secret length");
+		g_info ("received an encrypted secret structure with bad secret length");
 		return NULL;
 	}
 
@@ -439,7 +449,7 @@ service_decode_aes_secret (SecretSession *session,
 	if (!pkcs7_unpad_bytes_in_place (padded, &n_padded)) {
 		egg_secure_clear (padded, n_padded);
 		egg_secure_free (padded);
-		g_message ("received an invalid or unencryptable secret");
+		g_info ("received an invalid or unencryptable secret");
 		return FALSE;
 	}
 
@@ -448,6 +458,85 @@ service_decode_aes_secret (SecretSession *session,
 
 #endif /* WITH_GCRYPT */
 
+#ifdef WITH_GNUTLS
+
+static SecretValue *
+service_decode_aes_secret (SecretSession *session,
+                           gconstpointer param,
+                           gsize n_param,
+                           gconstpointer value,
+                           gsize n_value,
+                           const gchar *content_type)
+{
+	gnutls_cipher_hd_t cih;
+	gnutls_datum_t iv, key;
+	gsize n_padded;
+	int ret;
+	guchar *padded;
+
+	if (n_param != 16) {
+		g_info ("received an encrypted secret structure with invalid parameter");
+		return NULL;
+	}
+
+	if (n_value == 0 || n_value % 16 != 0) {
+		g_info ("received an encrypted secret structure with bad secret length");
+		return NULL;
+	}
+
+#if 0
+	g_printerr ("    lib iv:  %s\n", egg_hex_encode (param, n_param));
+#endif
+
+#if 0
+	g_printerr ("   lib key:  %s\n", egg_hex_encode (session->key, session->n_key));
+#endif
+
+	iv.data = (void *)param;
+	iv.size = n_param;
+	key.data = session->key;
+	key.size = session->n_key;
+	ret = gnutls_cipher_init (&cih, GNUTLS_CIPHER_AES_128_CBC, &key, &iv);
+	if (ret != 0) {
+		g_warning ("couldn't create AES cipher: %s", gnutls_strerror (ret));
+		return NULL;
+	}
+
+	/* Copy the memory buffer */
+	n_padded = n_value;
+	padded = egg_secure_alloc (n_padded);
+	if (!padded) {
+		gnutls_cipher_deinit (cih);
+		return NULL;
+	}
+	memcpy (padded, value, n_padded);
+
+	/* Perform the decryption */
+	ret = gnutls_cipher_decrypt2 (cih, padded, n_padded, padded, n_padded);
+	if (ret < 0) {
+		egg_secure_clear (padded, n_padded);
+		egg_secure_free (padded);
+		gnutls_cipher_deinit (cih);
+		return NULL;
+	}
+
+	gnutls_cipher_deinit (cih);
+
+	/* Unpad the resulting value */
+	if (!pkcs7_unpad_bytes_in_place (padded, &n_padded)) {
+		egg_secure_clear (padded, n_padded);
+		egg_secure_free (padded);
+		g_info ("received an invalid or unencryptable secret");
+		return FALSE;
+	}
+
+	return secret_value_new_full ((gchar *)padded, n_padded, content_type, egg_secure_free);
+}
+
+#endif /* WITH_GNUTLS */
+
+#endif /* WITH_CRYPTO */
+
 static SecretValue *
 service_decode_plain_secret (SecretSession *session,
                              gconstpointer param,
@@ -457,7 +546,7 @@ service_decode_plain_secret (SecretSession *session,
                              const gchar *content_type)
 {
 	if (n_param != 0) {
-		g_message ("received a plain secret structure with invalid parameter");
+		g_info ("received a plain secret structure with invalid parameter");
 		return NULL;
 	}
 
@@ -485,8 +574,8 @@ _secret_session_decode_secret (SecretSession *session,
 	g_variant_get_child (encoded, 0, "o", &session_path);
 
 	if (session_path == NULL || !g_str_equal (session_path, session->path)) {
-		g_message ("received a secret encoded with wrong session: %s != %s",
-		           session_path, session->path);
+		g_info ("received a secret encoded with wrong session: %s != %s",
+		        session_path, session->path);
 		g_free (session_path);
 		return NULL;
 	}
@@ -497,7 +586,7 @@ _secret_session_decode_secret (SecretSession *session,
 	value = g_variant_get_fixed_array (vvalue, &n_value, sizeof (guchar));
 	g_variant_get_child (encoded, 3, "s", &content_type);
 
-#ifdef WITH_GCRYPT
+#ifdef WITH_CRYPTO
 	if (session->key != NULL)
 		result = service_decode_aes_secret (session, param, n_param,
 		                                    value, n_value, content_type);
@@ -514,7 +603,7 @@ _secret_session_decode_secret (SecretSession *session,
 	return result;
 }
 
-#ifdef WITH_GCRYPT
+#ifdef WITH_CRYPTO
 
 static guchar*
 pkcs7_pad_bytes_in_secure_memory (gconstpointer secret,
@@ -536,6 +625,8 @@ pkcs7_pad_bytes_in_secure_memory (gconstpointer secret,
 	return padded;
 }
 
+#ifdef WITH_GCRYPT
+
 static gboolean
 service_encode_aes_secret (SecretSession *session,
                            SecretValue *value,
@@ -595,6 +686,72 @@ service_encode_aes_secret (SecretSession *session,
 
 #endif /* WITH_GCRYPT */
 
+#ifdef WITH_GNUTLS
+
+static gboolean
+service_encode_aes_secret (SecretSession *session,
+                           SecretValue *value,
+                           GVariantBuilder *builder)
+{
+	gnutls_cipher_hd_t cih = NULL;
+	guchar *padded;
+	gsize n_padded;
+	int ret;
+	gnutls_datum_t iv, key;
+	gpointer iv_data;
+	gconstpointer secret;
+	gsize n_secret;
+	GVariant *child;
+
+	g_variant_builder_add (builder, "o", session->path);
+
+	secret = secret_value_get (value, &n_secret);
+
+	/* Perform the encoding here */
+	padded = pkcs7_pad_bytes_in_secure_memory (secret, n_secret, &n_padded);
+	g_assert (padded != NULL);
+
+	/* Setup the IV */
+	iv_data = g_malloc0 (16);
+	iv.data = iv_data;
+	iv.size = 16;
+	ret = gnutls_rnd (GNUTLS_RND_NONCE, iv.data, iv.size);
+	g_return_val_if_fail (ret >= 0, FALSE);
+
+	/* Setup the key */
+	key.data = session->key;
+	key.size = session->n_key;
+
+	/* Create the cipher */
+	ret = gnutls_cipher_init (&cih, GNUTLS_CIPHER_AES_128_CBC, &key, &iv);
+	if (ret < 0) {
+		g_warning ("couldn't create AES cipher: %s", gnutls_strerror (ret));
+		return FALSE;
+	}
+
+	/* Perform the encryption */
+	ret = gnutls_cipher_encrypt2 (cih, padded, n_padded, padded, n_padded);
+	if (ret < 0) {
+		gnutls_cipher_deinit (cih);
+		return FALSE;
+	}
+
+	gnutls_cipher_deinit (cih);
+
+	child = g_variant_new_from_data (G_VARIANT_TYPE ("ay"), iv_data, 16, TRUE, g_free, iv_data);
+	g_variant_builder_add_value (builder, child);
+
+	child = g_variant_new_from_data (G_VARIANT_TYPE ("ay"), padded, n_padded, TRUE, egg_secure_free, padded);
+	g_variant_builder_add_value (builder, child);
+
+	g_variant_builder_add (builder, "s", secret_value_get_content_type (value));
+	return TRUE;
+}
+
+#endif /* WITH_GNUTLS */
+
+#endif /* WITH_CRYPTO */
+
 static gboolean
 service_encode_plain_secret (SecretSession *session,
                              SecretValue *value,
@@ -634,7 +791,7 @@ _secret_session_encode_secret (SecretSession *session,
 	type = g_variant_type_new ("(oayays)");
 	builder = g_variant_builder_new (type);
 
-#ifdef WITH_GCRYPT
+#ifdef WITH_CRYPTO
 	if (session->key)
 		ret = service_encode_aes_secret (session, value, builder);
 	else
